closedAtUs property
int?
get
closedAtUs
FlutterTimeline.now when the interaction settled, or null while it is
still open.
Implementation
int? get closedAtUs => _closedAtUs;
FlutterTimeline.now when the interaction settled, or null while it is
still open.
int? get closedAtUs => _closedAtUs;