target property
The ref, route or key the verb acted on; null for a verb without one
(blur, dismiss_modals).
Implementation
final String? target;
The ref, route or key the verb acted on; null for a verb without one
(blur, dismiss_modals).
final String? target;