node property
The SemanticsNode the entry was minted from, when the entry came from
a Semantics-tree walk. null for synthetic entries (e.g. find_by_text).
Implementation
final SemanticsNode? node;
The SemanticsNode the entry was minted from, when the entry came from
a Semantics-tree walk. null for synthetic entries (e.g. find_by_text).
final SemanticsNode? node;