The id install minted for this run of main(), answered by ext.dusk.boot_id; null before install.
main()
ext.dusk.boot_id
A hot restart re-runs main() and so mints a new one, on the web too, where the isolate id does not change.
static String? get bootId => _bootId;